@@ -58,8 +58,12 @@ read.zoo <- function(file, format = "", tz = "", FUN = NULL,
   if (is.list(index.column) && length(index.column) == 1 && 
 	index.column[[1]] == 1) index.column <- unlist(index.column)
 
-  is.index.column <- seq_along(rval) %in% unname(unlist(index.column)) |
-	names(rval) %in% unname(unlist(index.column))
+  is.index.column <- unname(unlist(index.column))
+  is.index.column <- if(is.numeric(is.index.column)) {
+     seq_along(rval) %in% is.index.column
+  } else {
+     seq_along(rval) %in% is.index.column | names(rval) %in% is.index.column
+ }
 
   name.to.num <- function(x) if (is.character(x))
 		match(x, names(rval), nomatch = 0) else x
@@ -283,12 +287,12 @@ read.delim2.zoo <- function(..., read = read.delim2) {
 }
 
 write.zoo <- function(x, file = "", index.name = "Index",
-  row.names = FALSE, col.names = NULL, ...)
+  row.names = FALSE, col.names = NULL, FUN = format, ...)
 {
   if(is.null(col.names)) col.names <- !is.null(colnames(x))
   dx <- as.data.frame(x)  
   stopifnot(all(names(dx) != index.name))
-  dx[[index.name]] <- as.character(index(x))
+  dx[[index.name]] <- FUN(index(x))
   dx <- dx[, c(ncol(dx), 1:(ncol(dx)-1))]
   write.table(dx, file = file, row.names = row.names, col.names = col.names, ...)
 }
