@@ -31,14 +31,14 @@ SEXP zoo_lag (SEXP x, SEXP _k, SEXP _pad)
 Rprintf("zoo_lag\n");
 #endif
   SEXP result;
-  int i,j;
+  R_xlen_t i,j;
   double *result_real=NULL;
   int    *result_int=NULL;
 
   int k=INTEGER(_k)[0] * -1; /* -1 is zoo convention */
   int k_positive = (k > 0) ? 1 : 0;
-  int nr = nrows(x);
-  int nc = ncols(x);
+  R_xlen_t nr = nrows(x);
+  R_xlen_t nc = ncols(x);
   int P=0;
   int PAD = INTEGER(coerceVector(_pad,INTSXP))[0];
 
@@ -49,11 +49,11 @@ Rprintf("zoo_lag\n");
     error("abs(k) must be less than nrow(x)");
 
   PROTECT(result = allocVector(TYPEOF(x), 
-          length(x) - (PAD ? 0 : abs(k)*nc))); P++;
+          xlength(x) - (PAD ? 0 : abs(k)*nc))); P++;
 
-  int nrr;
-  if(length(result) > 0)
-    nrr = (int)(length(result)/nc);
+  R_xlen_t nrr;
+  if(xlength(result) > 0)
+    nrr = (R_xlen_t)(xlength(result)/nc);
   else  /* handle zero-length objects */
     nrr = nr - (PAD ? 0 : abs(k));
 
@@ -266,7 +266,7 @@ Rprintf("zoo_lag\n");
   //} else {
     SEXP index, newindex;
     PROTECT(index = getAttrib(x, install("index"))); P++;
-    if(IS_S4_OBJECT(index)) {
+    if(isS4(index)) {
       /* should make this
          1) generic for any S4 object if possible
          2) test for timeDate as this is important
@@ -294,10 +294,11 @@ Rprintf("zoo_lag\n");
       default:
         break;
     }
-    if(IS_S4_OBJECT(getAttrib(x, install("index")))) {
+    if(isS4(getAttrib(x, install("index")))) {
       /* need to assure that this is timeDate */
       SEXP tmp = PROTECT(getAttrib(x, install("index"))); P++;
-      SEXP timeDate = PROTECT(NEW_OBJECT(MAKE_CLASS("timeDate"))); P++;
+      SEXP class = PROTECT(MAKE_CLASS("timeDate")); P++;
+      SEXP timeDate = PROTECT(NEW_OBJECT(class)); P++;
       copyMostAttrib(index,newindex);
       SET_SLOT(timeDate,install("Data"),newindex);
       SEXP format = PROTECT(GET_SLOT(tmp, install("format"))); P++;
@@ -326,6 +327,9 @@ Rprintf("zoo_lag\n");
 }
 
 SEXP zoo_lagts (SEXP x, SEXP _k, SEXP _pad) {
-  int k = INTEGER(_k)[0]*-1; /* change zoo default negative handling */
-  return zoo_lag (x, ScalarInteger(k), _pad);
+  int k_pos = INTEGER(_k)[0]*-1; /* change zoo default negative handling */
+  SEXP k = PROTECT(ScalarInteger(k_pos));
+  SEXP ans = zoo_lag (x, k, _pad);
+  UNPROTECT(1);
+  return ans;
 }
